# Installation

## Installation using PyPi

The easiest way to install XspecT is to use PyPi on the latest version of Python:

```bash
pip install xspect
```

Check if the installation was successful:

```bash
xspect --version
```

## Manual Installation

If you would like to manually install XspecT, clone the Github repository to a local working directory. You can now install XspecT by running:

```bash
pip install .
```

For development purposes, it is recommended to install the package in edit mode:

```bash
pip install -e '.[all]'
```

Check if the installation was successful:

```bash
xspect --version
```